@@ -47,6 +47,7 @@
 #include "symbol.h"
 #include "utils.h"
 #include "upoly.h"
+#include "normal.h"
 
 #include <algorithm>
 #include <map>
@@ -710,42 +711,5 @@ ex sqrfree_parfrac(const ex & a, const symbol & x)
 
 #endif // HAVE_LIBGIAC
 
-/** Resultant of two expressions e1,e2 with respect to symbol s.
- *  Method: Compute determinant of Sylvester matrix of e1,e2,s.  */
-ex resultantpoly(const ex & ee1, const ex & ee2, const ex & s)
-{
-	const int h1 = ee1.degree(s);
-	const int l1 = ee1.ldegree(s);
-	const int h2 = ee2.degree(s);
-	const int l2 = ee2.ldegree(s);
-
-	const int msize = h1 + h2;
-	matrix m(msize, msize);
-
-	for (int l = h1; l >= l1; --l) {
-		const ex e = ee1.coeff(s, l);
-		for (int k = 0; k < h2; ++k)
-			m(k, k+h1-l) = e;
-	}
-	for (int l = h2; l >= l2; --l) {
-		const ex e = ee2.coeff(s, l);
-		for (int k = 0; k < h1; ++k)
-			m(k+h2, k+h2-l) = e;
-	}
-
-	return m.determinant();
-}
-
-ex resultant(const ex & e1, const ex & e2, const ex & s)
-{
-	const ex ee1 = e1.expand();
-	const ex ee2 = e2.expand();
-	if (!ee1.info(info_flags::polynomial) ||
-	    !ee2.info(info_flags::polynomial))
-		throw(std::runtime_error("resultant(): arguments must be polynomials"));
-
-        return resultantpoly(ee1, ee2, s);
-}
-
 } // namespace GiNaC
 
