@@ -22,6 +22,8 @@
  */
 
 #include "pseries.h"
+#include "useries.h"
+#include "useries-flint.h"
 #include "add.h"
 #include "inifcns.h" // for Order function
 #include "lst.h"
@@ -267,7 +269,7 @@ size_t pseries::nops() const
 }
 
 /** Return the ith term in the series when represented as a sum. */
-ex pseries::op(size_t i) const
+const ex pseries::op(size_t i) const
 {
 	if (i >= seq.size())
 		throw (std::out_of_range("op() out of range"));
@@ -609,7 +611,7 @@ ex basic::series(const relational & r, int order, unsigned options) const
 		// We need to test for zero in order to see if the series terminates.
 		// The problem is that there is no such thing as a perfect test for
 		// zero.  Expanding the term occasionally helps a little...
-		deriv = deriv.diff(s).expand();
+		deriv = deriv.diff(s).expand(expand_options::expand_only_numerators);
 		if (deriv.is_zero())  // Series terminates
 			return pseries(r, seq);
 
@@ -620,7 +622,7 @@ ex basic::series(const relational & r, int order, unsigned options) const
 	
 	// Higher-order terms, if present
 	deriv = deriv.diff(s);
-	if (!deriv.expand().is_zero())
+        if (!deriv.expand(expand_options::expand_only_numerators).is_zero())
 		seq.push_back(expair(Order(_ex1), n));
 	return pseries(r, seq);
 }
@@ -1261,7 +1263,20 @@ ex ex::series(const ex & r, int order, unsigned options) const
 	else
 		throw (std::logic_error("ex::series(): expansion point has unknown type"));
 	
-	e = bp->series(rel_, order, options);
+        if ((options & series_options::try_univariate_flint) != 0u
+                        and rel_.rhs().is_zero()) {
+                options &= ~series_options::try_univariate_flint;
+	        if (useries_can_handle(*this)
+                        and has_symbol(rel_.lhs())) {
+                        try {
+                                return GiNaC::useries(*this, rel_, order, options);
+                        }
+                        catch(flint_error) {
+                                ;
+                        }
+                }
+        }
+        e = bp->series(rel_, order, options);
 	return e;
 }
 
